Struct BoundedVec
pub struct BoundedVec<T, const N: usize>(/* private fields */);Expand description
Wrapper for Vec that has an explicit upper bound on the number of elements.
The Structure remains heap-allocated to avoid blowing up the size of types where it is used.