Crate luk_chain[−][src]
Generalised BlockChain with associated network functionality and example chat application
Modules
Serializable/Deserializable structs to read/write config details for node
Main running code for all network interactions
Structs
Encapsulation of groups of events mined and stored on BlockChain
Struct to define local copy of blockchain
Events that are stored on [BlockChain]
Wrapper struct containing information needed for each user
Enums
Basic struct to show what can be stored on the [BlockChain]
Traits
Marker trait to define other traits which need to be implemented